/// <reference types="vite-plugin-svgr/client" />
import { Badge } from "./src/Badge";
import { Button } from "./src/Button";
import { Container } from "./src/Container";
import { Wrapper } from "./src/Wrapper";
import { Card } from "./src/Card";
import { Label } from "./src/Label";
import { PlanCard } from "./src/PlanCard";
import { Radio } from "./src/Radio";
import { ReactComponent as ActivityAlerts } from "./src/assets/svg/activity-alerts.svg";
import { ReactComponent as Alarm } from "./src/assets/svg/alarm.svg";
import { ReactComponent as Amex } from "./src/assets/svg/amex-logo.svg";
import { ReactComponent as ApplePay } from "./src/assets/svg/apple-pay-logo.svg";
import { ReactComponent as Battery } from "./src/assets/svg/battery.svg";
import { ReactComponent as Bill } from "./src/assets/svg/bill.svg";
import { ReactComponent as ChevronDown } from "./src/assets/svg/chevron-down.svg";
import { ReactComponent as Clock } from "./src/assets/svg/clock.svg";
import { ReactComponent as Close } from "./src/assets/svg/close-icon.svg";
import { ReactComponent as Configure } from "./src/assets/svg/configure.svg";
import { ReactComponent as ContactSensor } from "./src/assets/svg/contact-sensor.svg";
import { ReactComponent as CreditCard } from "./src/assets/svg/credit-card.svg";
import { ReactComponent as FriendInvite } from "./src/assets/svg/friend-invite.svg";
import { ReactComponent as GBP } from "./src/assets/svg/gbp.svg";
import { ReactComponent as GeoPoint } from "./src/assets/svg/geo-point.svg";
import { ReactComponent as GooglePayLogo } from "./src/assets/svg/google-pay-logo.svg";
import { ReactComponent as GroupOfPeople } from "./src/assets/svg/group-of-people.svg";
import { ReactComponent as HelpAndSupport } from "./src/assets/svg/help-and-support.svg";
import { ReactComponent as Info } from "./src/assets/svg/info-icon.svg";
import { ReactComponent as Integrations } from "./src/assets/svg/integrations.svg";
import { ReactComponent as Klarna } from "./src/assets/svg/klarna-logo.svg";
import { ReactComponent as LightBulb } from "./src/assets/svg/lightbulb.svg";
import { ReactComponent as Placeholder } from "./src/assets/svg/placeholder.svg";
import { ReactComponent as MasterCard } from "./src/assets/svg/mastercard-logo.svg";
import { ReactComponent as Minus } from "./src/assets/svg/minus-red.svg";
import { ReactComponent as NightSet } from "./src/assets/svg/night-set.svg";
import { ReactComponent as Notifications } from "./src/assets/svg/notifications.svg";
import { ReactComponent as PartialArm } from "./src/assets/svg/partial-arm.svg";
import { ReactComponent as PayPal } from "./src/assets/svg/paypal-logo.svg";
import { ReactComponent as Phone } from "./src/assets/svg/phone.svg";
import { ReactComponent as Plus } from "./src/assets/svg/plus-green.svg";
import { ReactComponent as Police } from "./src/assets/svg/police.svg";
import { ReactComponent as ReactLogo } from "./src/assets/svg/react.svg";
import { ReactComponent as Switch } from "./src/assets/svg/switch.svg";
import { ReactComponent as Truck } from "./src/assets/svg/truck.svg";
import { ReactComponent as Update } from "./src/assets/svg/update.svg";
import { ReactComponent as Visa } from "./src/assets/svg/visa-logo.svg";

import "./src/scss/global.scss";

const primaryButtons = [
  {
    variant: "primary",
    iconPosition: false,
    size: "2xl",
  },
  {
    variant: "primary",
    iconPosition: "iconLeft",
    size: "2xl",
  },
  {
    variant: "primary",
    iconPosition: "iconRight",
    size: "2xl",
  },
  {
    variant: "primary",
    iconPosition: false,
    size: "xl",
  },
  {
    variant: "primary",
    iconPosition: "iconLeft",
    size: "xl",
  },
  {
    variant: "primary",
    iconPosition: "iconRight",
    size: "xl",
  },
  {
    variant: "primary",
    iconPosition: false,
    size: "lg",
  },
  {
    variant: "primary",
    iconPosition: "iconLeft",
    size: "lg",
  },
  {
    variant: "primary",
    iconPosition: "iconRight",
    size: "lg",
  },
  {
    variant: "primary",
    iconPosition: false,
    size: "md",
  },
  {
    variant: "primary",
    iconPosition: "iconLeft",
    size: "md",
  },
  {
    variant: "primary",
    iconPosition: "iconRight",
    size: "md",
  },
  {
    variant: "primary",
    iconPosition: false,
    size: "sm",
  },
  {
    variant: "primary",
    iconPosition: "iconLeft",
    size: "sm",
  },
  {
    variant: "primary",
    iconPosition: "iconRight",
    size: "sm",
  },
];
const secondaryButtons = [
  {
    variant: "secondary",
    iconPosition: false,
    size: "2xl",
  },
  {
    variant: "secondary",
    iconPosition: "iconLeft",
    size: "2xl",
  },
  {
    variant: "secondary",
    iconPosition: "iconRight",
    size: "2xl",
  },
  {
    variant: "secondary",
    iconPosition: false,
    size: "xl",
  },
  {
    variant: "secondary",
    iconPosition: "iconLeft",
    size: "xl",
  },
  {
    variant: "secondary",
    iconPosition: "iconRight",
    size: "xl",
  },
  {
    variant: "secondary",
    iconPosition: false,
    size: "lg",
  },
  {
    variant: "secondary",
    iconPosition: "iconLeft",
    size: "lg",
  },
  {
    variant: "secondary",
    iconPosition: "iconRight",
    size: "lg",
  },
  {
    variant: "secondary",
    iconPosition: false,
    size: "md",
  },
  {
    variant: "secondary",
    iconPosition: "iconLeft",
    size: "md",
  },
  {
    variant: "secondary",
    iconPosition: "iconRight",
    size: "md",
  },
  {
    variant: "secondary",
    iconPosition: false,
    size: "sm",
  },
  {
    variant: "secondary",
    iconPosition: "iconLeft",
    size: "sm",
  },
  {
    variant: "secondary",
    iconPosition: "iconRight",
    size: "sm",
  },
];
const plainButtons = [
  {
    variant: "plain",
    iconPosition: false,
    size: "2xl",
  },
  {
    variant: "plain",
    iconPosition: "iconLeft",
    size: "2xl",
  },
  {
    variant: "plain",
    iconPosition: "iconRight",
    size: "2xl",
  },
  {
    variant: "plain",
    iconPosition: false,
    size: "xl",
  },
  {
    variant: "plain",
    iconPosition: "iconLeft",
    size: "xl",
  },
  {
    variant: "plain",
    iconPosition: "iconRight",
    size: "xl",
  },
  {
    variant: "plain",
    iconPosition: false,
    size: "lg",
  },
  {
    variant: "plain",
    iconPosition: "iconLeft",
    size: "lg",
  },
  {
    variant: "plain",
    iconPosition: "iconRight",
    size: "lg",
  },
  {
    variant: "plain",
    iconPosition: false,
    size: "md",
  },
  {
    variant: "plain",
    iconPosition: "iconLeft",
    size: "md",
  },
  {
    variant: "plain",
    iconPosition: "iconRight",
    size: "md",
  },
  {
    variant: "plain",
    iconPosition: false,
    size: "sm",
  },
  {
    variant: "plain",
    iconPosition: "iconLeft",
    size: "sm",
  },
  {
    variant: "plain",
    iconPosition: "iconRight",
    size: "sm",
  },
];

const App = () => {
  return (
    <div className="app p-5">
      <Wrapper size="lg">
        <h1 className="mb-4">Boundary Web UI Kit</h1>
        <h2>Icons</h2>
        <Container size="xxl">
          <div className="row">
            <div className="col">
              <Alarm />
            </div>
            <div className="col">
              <ActivityAlerts />
            </div>
            <div className="col">
              <Alarm />
            </div>
            <div className="col">
              <Amex />
            </div>
            <div className="col">
              <ApplePay />
            </div>
            <div className="col">
              <Battery />
            </div>
            <div className="col">
              <Bill />
            </div>
            <div className="col">
              <ChevronDown />
            </div>
            <div className="col">
              <Clock />
            </div>
            <div className="col">
              <Close />
            </div>
            <div className="col">
              <Configure />
            </div>
            <div className="col">
              <ContactSensor />
            </div>
            <div className="col">
              <CreditCard />
            </div>
            <div className="col">
              <FriendInvite />
            </div>
            <div className="col">
              <GBP />
            </div>
            <div className="col">
              <GeoPoint />
            </div>
            <div className="col">
              <GooglePayLogo />
            </div>
            <div className="col">
              <GroupOfPeople />
            </div>
            <div className="col">
              <HelpAndSupport />
            </div>
            <div className="col">
              <Info />
            </div>
            <div className="col">
              <Integrations />
            </div>
            <div className="col">
              <Klarna />
            </div>
            <div className="col">
              <LightBulb />
            </div>
            <div className="col">
              <Placeholder />
            </div>
            <div className="col">
              <MasterCard />
            </div>
            <div className="col">
              <Minus />
            </div>
            <div className="col">
              <NightSet />
            </div>
            <div className="col">
              <Notifications />
            </div>
            <div className="col">
              <PartialArm />
            </div>
            <div className="col">
              <PayPal />
            </div>
            <div className="col">
              <Phone />
            </div>
            <div className="col">
              <Plus />
            </div>
            <div className="col">
              <Police />
            </div>
            <div className="col">
              <ReactLogo />
            </div>
            <div className="col">
              <Switch />
            </div>
            <div className="col">
              <Truck />
            </div>
            <div className="col">
              <Update />
            </div>
            <div className="col">
              <Visa />
            </div>
          </div>
        </Container>

        <h2 className="mb-4">Badges</h2>
        <Badge>This is a badge</Badge>
        <br />
        <h2 className="mb-4">Buttons</h2>

        <div className="button-grid mb-8">
          {[...primaryButtons, ...secondaryButtons, ...plainButtons].map(
            (el) => (
              <div>
                <Button
                  variant={
                    el?.variant as "primary" | "secondary" | "plain" | undefined
                  }
                  {...(el?.iconPosition === "iconLeft" && {
                    iconLeft: <Placeholder />,
                  })}
                  {...(el?.iconPosition === "iconRight" && {
                    iconRight: <Placeholder />,
                  })}
                  size={el?.size as "2xl" | "xl" | "lg" | "md" | "sm"}
                  onClick={() =>
                    console.log("you clicked?", { position: <Placeholder /> })
                  }
                >
                  Button
                </Button>
              </div>
            )
          )}
        </div>

        <div className="mb-8">
          <h2 className="mb-4">Cards</h2>
          <div className="d-flex justify-content-between">
            <Card fullWidth className="me-1">
              <h1>Card Title</h1>
              <ul>
                <li>This is a card</li>
                <li>You can put anyting in a card</li>
              </ul>
            </Card>
            <Card fullWidth className="ms-1">
              <h1>Card Title</h1>
              <ul>
                <li>This is a card</li>
                <li>You can put anyting in a card</li>
              </ul>
            </Card>
          </div>
        </div>

        <h2 className="mb-4">Plan Cards</h2>
        <div className="container p-0">
          <div className="row">
            <div className="col">
              <PlanCard
                fullWidth
                selectPlan={(id) => console.log("you selected plan", id)}
                plan={{
                  title: "Pro",
                  id: 1,
                  productID: 1,
                  price: 9.99,
                  highlightFeatures: [
                    {
                      term_id: 1,
                      name: "24/7 Professional Monitoring",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                    {
                      term_id: 2,
                      name: "Level 1 immediate Police Response request",
                      description: "Level 1 immediate Police Response request",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                    {
                      term_id: 3,
                      name: "Annual Engineer Visit",
                      description: "Level 1 immediate Police Response request",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  features: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "Annual Engineer Visit",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  allFeatures: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                }}
              />
            </div>
            <div className="col">
              <PlanCard
                fullWidth
                selectPlan={(id) => console.log("you selected plan", id)}
                plan={{
                  title: "Smart",
                  id: 1,
                  productID: 1,
                  price: 10,
                  highlightFeatures: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  features: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  allFeatures: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                }}
              />
            </div>
            <div className="col">
              <PlanCard
                fullWidth
                selectPlan={(id) => console.log("you selected plan", id)}
                plan={{
                  title: "Lite",
                  id: 1,
                  productID: 3,
                  price: 0,
                  highlightFeatures: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  features: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                  allFeatures: [
                    {
                      term_id: 1,
                      name: "Feature 1",
                      description: "This is a feature",
                      svg: "<svg></svg>",
                      customValue: false,
                    },
                  ],
                }}
              />
            </div>
          </div>
        </div>

        <div className="mb-8">
          <h2 className="mb-4">Labels</h2>
          <Label>This is a label</Label>
        </div>

        <div className="mb-8">
          <h2 className="mb-4">Radio Buttons</h2>
          <Radio value={"yes"} name="test" labelText="This is a radio button" />
          <Radio value={"no"} name="test" labelText="This is a radio button" />
        </div>
      </Wrapper>
    </div>
  );
};

export { App };
